@@ -1,4 +1,4 @@
-from decipher.beacon import KEYLEN, BeaconAPIException
+from decipher.beacon import BeaconAPIException, FULLKEY
 import requests
 import time
 
@@ -26,7 +26,7 @@ def login(api, args):
     while 1:
         print
         print "How do you want to authenticate?"
-        print "1. Enter the %d-character API key (valid until deactivated)" % KEYLEN
+        print "1. Enter the %d-character API key (valid until deactivated)" % FULLKEY
         print "2. Enter your username/password (temporary login)"
         print "3. Enter a long code (visible on the API key page)"
         print "q. Quit"
@@ -47,8 +47,8 @@ def login(api, args):
         key = None
         while 1:
             key = raw_input("API KEY: ")
-            if len(key) != KEYLEN:
-                print "An API key is exactly %d characters long" % KEYLEN
+            if len(key) != FULLKEY:
+                print "An API key is exactly %d characters long" % FULLKEY
                 print "If you lost your secret key part, you must rekey your key."
             else:
                 break
